==> jc-1.4.0.tar.gz: soot/BodyPack.h <==
// public class soot.BodyPack

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class cd3a66046895aece soot_BodyPack
// @dep_class 65aca5ceab69719a soot_Pack

// header file dependencies
// @dep_header soot_Pack

#include "soot/Pack.h"

#ifndef _JC_soot_BodyPack_H_
#define _JC_soot_BodyPack_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Body$object;

// Typedefs
typedef struct _jc_soot_BodyPack$sub_refs	_jc_soot_BodyPack$sub_refs;
typedef struct _jc_soot_BodyPack$sub_nonrefs	_jc_soot_BodyPack$sub_nonrefs;
typedef struct _jc_soot_BodyPack$refs	_jc_soot_BodyPack$refs;
typedef struct _jc_soot_BodyPack$nonrefs	_jc_soot_BodyPack$nonrefs;
typedef struct _jc_soot_BodyPack$object	_jc_soot_BodyPack$object;

typedef const struct _jc_soot_BodyPack$vmethods	_jc_soot_BodyPack$vmethods;
typedef const struct _jc_soot_BodyPack$vtable	_jc_soot_BodyPack$vtable;
typedef const struct _jc_soot_BodyPack$vtype	_jc_soot_BodyPack$vtype;

// Constructors
extern void _jc_soot_BodyPack$method$_init$c31b894660454d13(_jc_env *, struct _jc_soot_BodyPack$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern void _jc_soot_BodyPack$method$internalApply$8c8b8fe09b775776(_jc_env *, struct _jc_soot_BodyPack$object *, struct _jc_soot_Body$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_BodyPack$method_info$internalApply$8c8b8fe09b775776;

// Virtual methods structure
struct _jc_soot_BodyPack$vmethods {
	void	(*internalApply$8c8b8fe09b775776)(_jc_env *, struct _jc_soot_BodyPack$object *, struct _jc_soot_Body$object *);
};

// Vtable
struct _jc_soot_BodyPack$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Pack$vmethods	soot_Pack;
	_jc_soot_BodyPack$vmethods	soot_BodyPack;
};

// Vtype
struct _jc_soot_BodyPack$vtype {
	_jc_type			type;
	_jc_soot_BodyPack$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_BodyPack$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_BodyPack$refs {
    _jc_soot_BodyPack$sub_refs	soot_BodyPack;
    _jc_soot_Pack$sub_refs	soot_Pack;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_BodyPack$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_BodyPack$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Pack$sub_nonrefs	soot_Pack;
    _jc_soot_BodyPack$sub_nonrefs	soot_BodyPack;
};

// Object instance structure
struct _jc_soot_BodyPack$object {
	_jc_soot_BodyPack$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_BodyPack$vtype	*vtype;
	_jc_soot_BodyPack$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_BodyPack$vtype _jc_soot_BodyPack$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_BodyPack, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_BodyPack$class_object;

#endif	/* _JC_soot_BodyPack_H_ */

==> jc-1.4.6.tar.gz: soot/BodyPack.h <==
// public class soot.BodyPack

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class cd3a66046895aece soot_BodyPack
// @dep_class 65aca5ceab69719a soot_Pack

// header file dependencies
// @dep_header soot_Pack

#include "soot/Pack.h"

#ifndef _JC_soot_BodyPack_H_
#define _JC_soot_BodyPack_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Body$object;

// Typedefs
typedef struct _jc_soot_BodyPack$sub_refs	_jc_soot_BodyPack$sub_refs;
typedef struct _jc_soot_BodyPack$sub_nonrefs	_jc_soot_BodyPack$sub_nonrefs;
typedef struct _jc_soot_BodyPack$refs	_jc_soot_BodyPack$refs;
typedef struct _jc_soot_BodyPack$nonrefs	_jc_soot_BodyPack$nonrefs;
typedef struct _jc_soot_BodyPack$object	_jc_soot_BodyPack$object;

typedef const struct _jc_soot_BodyPack$vmethods	_jc_soot_BodyPack$vmethods;
typedef const struct _jc_soot_BodyPack$vtable	_jc_soot_BodyPack$vtable;
typedef const struct _jc_soot_BodyPack$vtype	_jc_soot_BodyPack$vtype;

// Constructors
extern void _jc_soot_BodyPack$method$_init$c31b894660454d13(_jc_env *, struct _jc_soot_BodyPack$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_BodyPack$method$internalApply$8c8b8fe09b775776(_jc_env *, struct _jc_soot_BodyPack$object *, struct _jc_soot_Body$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_BodyPack$method_info$internalApply$8c8b8fe09b775776;

// Virtual methods structure
struct _jc_soot_BodyPack$vmethods {
	void	(*internalApply$8c8b8fe09b775776)(_jc_env *, struct _jc_soot_BodyPack$object *, struct _jc_soot_Body$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_BodyPack$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Pack$vmethods	soot_Pack;
	_jc_soot_BodyPack$vmethods	soot_BodyPack;
};

// Vtype
struct _jc_soot_BodyPack$vtype {
	_jc_type			type;
	_jc_soot_BodyPack$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_BodyPack$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_BodyPack$refs {
    _jc_soot_BodyPack$sub_refs	soot_BodyPack;
    _jc_soot_Pack$sub_refs	soot_Pack;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_BodyPack$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_BodyPack$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Pack$sub_nonrefs	soot_Pack;
    _jc_soot_BodyPack$sub_nonrefs	soot_BodyPack;
};

// Object instance structure
struct _jc_soot_BodyPack$object {
	_jc_soot_BodyPack$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_BodyPack$vtype	*vtype;
	_jc_soot_BodyPack$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_BodyPack$vtype _jc_soot_BodyPack$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_BodyPack, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_BodyPack$class_object;

#endif	/* _JC_soot_BodyPack_H_ */
